@@ -24,7 +24,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
         this._plugin = plugin;
         this._urlActions = [];
         this._buttonMap = {};
-        this._mmButtonMap = {};
         this._buttonSetMap = {};
         this._cfg = cfg;
         this._populate(cfg, buttonClass, getFormData);
@@ -116,7 +115,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
         _tableMenu: null,
         _defaultAction: null,
         _buttonMap: null,
-        _mmButtonMap: null,
         _urlActions: null,
         _mobileMenu: null,
         _print(content, left, top) {
@@ -174,10 +172,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                 + (btCfg.testingIdPostfix ? btCfg.testingIdPostfix : '')
                                 + 'mmButton';
                             this.addOwnedQxObject(mmButton, mmBtnId);
-                            this._mmButtonMap[btCfg.key] = mmButton;
                         }
+                        this._bindButtonPropperties(button, mmButton);
                         return;
-                        break;
                     case 'save':
                     case 'submitVerify':
                     case 'submit':
@@ -196,7 +193,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         }
                         if (btCfg.key) {
                             this._buttonMap[btCfg.key] = button;
-                            this._mmButtonMap[btCfg.key] = mmButton;
                             let urlAction = btCfg.urlAction;
                             if (urlAction) {
                                 this._urlActions.push({
@@ -278,8 +274,15 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         }, this);
                         break;
                     case 'upload':
-                        button = this._makeUploadButton(cfg, btCfg, getFormData);
-                        mmButton = this._makeUploadButton(cfg, btCfg, getFormData, callbackery.ui.form.FileSelectorMenuButton);
+                        button = this._makeUploadButton(cfg, btCfg, getFormData,
+                            buttonClass == qx.ui.tolbar.Button
+                                ? qx.ui.toolbar.FileSelectorButton
+                                : qx.ui.form.FileSelectorButton);
+                        mmButton = this._makeUploadButton(cfg, btCfg, getFormData,
+                            callbackery.ui.form.FileSelectorMenuButton);
+                        if (btCfg.key) {
+                            this._buttonMap[btCfg.key] = button;
+                        }
                         break;
                     case 'separator':
                         this.add(new qx.ui.core.Spacer(10, 10));
@@ -488,20 +491,20 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     menuButton.addListener('execute', action, this);
                     tm.add(menuButton);
                 }
+                if (button && manuButton) {
+                    this._bindButtonProperties(button, mmButton);
+                }
             }, this);
         },
         _makeUploadButton(cfg, btCfg, getFormData, buttonClass) {
             var button;
             var label = btCfg.label ? this.xtr(btCfg.label) : null;
-            if (buttonClass === qx.ui.toolbar.Button) {
-                button = new qx.ui.toolbar.FileSelectorButton(label);
+            if (buttonClass) {
+                button = new buttonClass(label);
             }
             else {
                 button = new qx.ui.form.FileSelectorButton(label);
             }
-            if (btCfg.key) {
-                this._buttonMap[btCfg.key] = button;
-            }
             if (btCfg.buttonSet) {
                 var bs = btCfg.buttonSet;
                 if (bs.label) {
@@ -605,5 +608,10 @@ qx.Class.define("callbackery.ui.plugin.Action", {
         for (const [key, btn] of Object.entries(this._buttonMap)) {
             btn.destroy();
         }
+    },
+    _bindButtonProperties(button, mmButton) {
+        ['visibility', 'enabled', 'label', 'icon'].forEach((prop) => {
+            button.bind(prop, mmButton, prop);
+        });
     }
 });
